From 7865882459103728f8ead677789db9f5a5a2ae93 Mon Sep 17 00:00:00 2001
From: Thiago Caserta <caserta@movestax.com>
Date: Tue, 24 Mar 2026 16:32:38 -0300
Subject: [PATCH v1] Fix typos in pg_bsd_indent: "dont" -> "don't" in comments

Fix ten instances of missing apostrophe in contractions within
code comments across pg_bsd_indent source files.

Co-Authored-By: Claude Opus 4.6 <noreply@anthropic.com>
---
 src/tools/pg_bsd_indent/indent.c     | 14 +++++++-------
 src/tools/pg_bsd_indent/io.c         |  2 +-
 src/tools/pg_bsd_indent/pr_comment.c |  4 ++--
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/src/tools/pg_bsd_indent/io.c b/src/tools/pg_bsd_indent/io.c
index 9d64ca1ee56..62d600bbb11 100644
--- a/src/tools/pg_bsd_indent/io.c
+++ b/src/tools/pg_bsd_indent/io.c
@@ -97,7 +97,7 @@ dump_line(void)
 	    putc('\n', output);
 	n_real_blanklines = 0;
 	if (ps.ind_level == 0)
-	    ps.ind_stmt = 0;	/* this is a class A kludge. dont do
+	    ps.ind_stmt = 0;	/* this is a class A kludge. don't do
 				 * additional statement indentation if we are
 				 * at bracket level 0 */
 
diff --git a/src/tools/pg_bsd_indent/pr_comment.c b/src/tools/pg_bsd_indent/pr_comment.c
index a9572b39ffe..7dd0f59e3f7 100644
--- a/src/tools/pg_bsd_indent/pr_comment.c
+++ b/src/tools/pg_bsd_indent/pr_comment.c
@@ -117,7 +117,7 @@ pr_comment(void)
 	if ( /* ps.bl_line && */ (s_lab == e_lab) && (s_code == e_code)) {
 	    /* klg: check only if this line is blank */
 	    /*
-	     * If this (*and previous lines are*) blank, dont put comment way
+	     * If this (*and previous lines are*) blank, don't put comment way
 	     * out at left
 	     */
 	    ps.com_col = (ps.ind_level - ps.unindent_displace) * ps.ind_size + 1;
@@ -234,7 +234,7 @@ pr_comment(void)
 	    last_bl = NULL;
 	    CHECK_SIZE_COM(4);
 	    if (ps.box_com || ps.last_nl) {	/* if this is a boxed comment,
-						 * we dont ignore the newline */
+						 * we don't ignore the newline */
 		if (s_com == e_com)
 		    *e_com++ = ' ';
 		if (!ps.box_com && e_com - s_com > 3) {
diff --git a/src/tools/pg_bsd_indent/indent.c b/src/tools/pg_bsd_indent/indent.c
index 421592db928..736f350f145 100644
--- a/src/tools/pg_bsd_indent/indent.c
+++ b/src/tools/pg_bsd_indent/indent.c
@@ -229,7 +229,7 @@ main(int argc, char **argv)
     }
 
     if (ps.com_ind <= 1)
-	ps.com_ind = 2;		/* dont put normal comments before column 2 */
+	ps.com_ind = 2;		/* don't put normal comments before column 2 */
     if (block_comment_max_col <= 0)
 	block_comment_max_col = max_col;
     if (ps.local_decl_indent < 0)	/* if not specified by user, set this */
@@ -483,7 +483,7 @@ check_type:
 		if (verbose)
 		    diag2(0, "Line broken");
 		dump_line();
-		ps.want_blank = false;	/* dont insert blank at line start */
+		ps.want_blank = false;	/* don't insert blank at line start */
 		force_nl = false;
 	    }
 	    ps.in_stmt = true;	/* turn on flag which causes an extra level of
@@ -604,7 +604,7 @@ check_type:
 		force_nl = true;/* must force newline after if */
 		ps.last_u_d = true;	/* inform lexi that a following
 					 * operator is unary */
-		ps.in_stmt = false;	/* dont use stmt continuation
+		ps.in_stmt = false;	/* don't use stmt continuation
 					 * indentation */
 
 		parse(hd_type);	/* let parser worry about if, or whatever */
@@ -750,7 +750,7 @@ check_type:
 		if (sp_sw) {	/* this is a check for an if, while, etc. with
 				 * unbalanced parens */
 		    sp_sw = false;
-		    parse(hd_type);	/* dont lose the if, or whatever */
+		    parse(hd_type);	/* don't lose the if, or whatever */
 		}
 	    }
 	    *e_code++ = ';';
@@ -765,7 +765,7 @@ check_type:
 	    break;
 
 	case lbrace:		/* got a '{' */
-	    ps.in_stmt = false;	/* dont indent the {} */
+	    ps.in_stmt = false;	/* don't indent the {} */
 	    if (!ps.block_init)
 		force_nl = true;/* force other stuff on same line as '{' onto
 				 * new line */
@@ -803,7 +803,7 @@ check_type:
 		}
 	    }
 	    if (s_code == e_code)
-		ps.ind_stmt = false;	/* dont put extra indentation on line
+		ps.ind_stmt = false;	/* don't put extra indentation on line
 					 * with '{' */
 	    if (ps.in_decl && ps.in_or_st) {	/* this is either a structure
 						 * declaration or an init */
@@ -1014,7 +1014,7 @@ check_type:
 	case period:		/* treat a period kind of like a binary
 				 * operation */
 	    *e_code++ = '.';	/* move the period into line */
-	    ps.want_blank = false;	/* dont put a blank after a period */
+	    ps.want_blank = false;	/* don't put a blank after a period */
 	    break;
 
 	case comma:
-- 
2.53.0

